@@ -5,6 +5,9 @@ use warnings FATAL => 'all';
 eval "use Color::Spectrum";
 our $NO_SPECTRUM = $@;
 
+eval "use Encode::Wechsler";
+our $NO_WECHSLER = $@;
+
 sub conway {
     my ($self,$data,$args);
     $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
@@ -18,6 +21,25 @@ sub conway {
 
     $args->{interval} ||= 200;
 
+    if ($args->{wechsler} and not $NO_WECHSLER) {
+        my $wechsler = Encode::Wechsler->new( pad => 1 );
+        my @grid;
+        eval { @grid = $wechsler->decode( $args->{wechsler} ) };
+        if ($@) {
+            $args->{data} = [[ 'Error' ],[ $@ ]];
+            return $self ? $self->generate( %$args ) : Spreadsheet::HTML::generate( %$args );
+        }
+
+        $args->{_max_rows} = scalar @grid;
+        $args->{_max_cols} = scalar @{ $grid[0] };
+
+        for my $row (0 .. $#grid) {
+            for my $col (0 .. $#{ $grid[$row] } ) {
+                $args->{"-r${row}c${col}"} = $grid[$row][$col] if $grid[$row][$col];
+            }
+        }
+    }
+
     my ( @cells, @ids );
     for my $r ( 0 .. $args->{_max_rows} - 1 ) {
         for my $c ( 0 .. $args->{_max_cols} - 1 ) {
@@ -38,6 +60,7 @@ sub conway {
     }
 
     # find and remove 'file' param and its value if found
+    # because it was already processed via ::File::Loader by way of _args()
     if ($args->{file} and $args->{file} =~ /\.(gif|png|jpe?g)$/) {
         my $index = 0;
         for (0 .. $#_) {
@@ -51,6 +74,8 @@ sub conway {
     my @args = (
         @cells,
         data    => $data,
+        ( $args->{wechsler} ? (matrix => 1) : () ),
+        ( $args->{wechsler} ? (fill => join 'x', $args->{_max_rows}, $args->{_max_cols}) : () ),
         caption => { '<button id="toggle" onClick="toggle()">Start</button>' => { align => 'bottom' } },
         @_,
     );
@@ -212,7 +237,7 @@ Instead, use the Spreadsheet::HTML interface:
 
 =over 4
 
-=item * C<conway( on, off, colors, fade, interval, jquery, %params )>
+=item * C<conway( wechsler, on, off, colors, fade, interval, jquery, %params )>
 
 Game of life. From an implementation i wrote back in college.
 
@@ -222,8 +247,12 @@ Set the timer with C<interval> (defaults to 200 miliseconds).
 
   conway( interval => 75 )
 
-If you have L<Color::Spectrum> installed then you can
-activate a fading effect like so:
+If you have L<Encode::Wechsler> installed then you can preload the game board
+with any valid Wechsler Code:
+
+  conway( wechsler => 'xp3_0ggmligkcz32w46' )
+
+If you have L<Color::Spectrum> installed then you can activate a fading effect like so:
 
   conway( on => '#FF0000', off => '#999999', fade => 1 )
 
@@ -256,6 +285,10 @@ The interface for this functionality.
 
 More presets.
 
+=item L<Encode::Wechsler>
+
+Wechsler encoder/decoder for Conway's Game of Life boards.
+
 =item L<Color::Spectrum>
 
 Generates spectrums of HTML color strings.
